@@ -20,6 +20,7 @@ from marshmallow.orderedset import OrderedSet
 from marshmallow.decorators import (PRE_DUMP, POST_DUMP, PRE_LOAD, POST_LOAD,
                                     VALIDATES, VALIDATES_SCHEMA)
 from marshmallow.utils import missing
+from marshmallow.warnings import RemovedInMarshmallow3Warning, ChangedInMarshmallow3Warning
 
 
 #: Return type of :meth:`Schema.dump` including serialized data and errors
@@ -195,7 +196,17 @@ class SchemaOpts(object):
         if not isinstance(self.exclude, (list, tuple)):
             raise ValueError("`exclude` must be a list or tuple.")
         self.strict = getattr(meta, 'strict', False)
+        if hasattr(meta, 'dateformat'):
+            warnings.warn(
+                "The dateformat option is renamed to datetimeformat in marshmallow 3.",
+                ChangedInMarshmallow3Warning
+            )
         self.dateformat = getattr(meta, 'dateformat', None)
+        if hasattr(meta, 'json_module'):
+            warnings.warn(
+                "The json_module option is renamed to render_module in marshmallow 3.",
+                ChangedInMarshmallow3Warning
+            )
         self.json_module = getattr(meta, 'json_module', json)
         if hasattr(meta, 'skip_missing'):
             warnings.warn(
@@ -336,6 +347,12 @@ class BaseSchema(base.SchemaABC):
         self.many = many
         self.only = only
         self.exclude = exclude
+        if prefix:
+            warnings.warn(
+                'The `prefix` argument is deprecated. Use a post_dump '
+                'method to insert a prefix instead.',
+                RemovedInMarshmallow3Warning
+            )
         self.prefix = prefix
         self.strict = strict if strict is not None else self.opts.strict
         self.ordered = self.opts.ordered
@@ -348,7 +365,7 @@ class BaseSchema(base.SchemaABC):
             warnings.warn(
                 'The `extra` argument is deprecated. Use a post_dump '
                 'method to add additional data instead.',
-                DeprecationWarning
+                RemovedInMarshmallow3Warning
             )
         self.extra = extra
         self.context = context or {}
@@ -732,7 +749,7 @@ class BaseSchema(base.SchemaABC):
                 if set_operation == 'union':
                     new_options |= self.set_class(original_options)
                 if set_operation == 'intersection':
-                        new_options &= self.set_class(original_options)
+                    new_options &= self.set_class(original_options)
             setattr(self.declared_fields[key], option_name, new_options)
 
     def _update_fields(self, obj=None, many=False):
